@@ -1,3 +1,4 @@
+from typing import List
 from eospy.types import Transaction
 from eospy.utils import sig_digest
 import pytz
@@ -17,9 +18,9 @@ class MultiSigClient():
     - Contract
     """
     def __init__(self, 
-            private_keys: list=[], 
-            cookies: list=[],  
-            *clients: Client,
+            private_keys: list = [], 
+            cookies: list = [],  
+            clients: List[Client] = [],
             node: str='https://wax.greymass.com'):
 
         self.node = node
@@ -77,10 +78,10 @@ class TX():
     def get_trx_extend_info(self):
         trx_wallets = []
         for action in list(self.actions):
-            trx_wallets.append(action['authorization'][0]['actor'])
+            trx_wallets.append(action.result['authorization'][0]['actor'])
 
         transaction = {
-            "actions": self.actions
+            "actions": [a.result for a in self.actions]
         }
             
         transaction['expiration'] = str(
